##### Flip Book Page

A Flip Book page lets you flip through a number of pages. If, for example, you want to showcase your data on different pages or show a number of case studies, this page type comes in handy. To create a flip book, you need to create a parent page of the type Flip Book and then the child pages (any type is fine, but you'll probably only need template pages). Each child page needs to specify the flip book page as its parent.

###### How to create a Flip Book

- Go to Manage Pages > Create New Page to create a new page. Choose flip book as its type. Fill out the required fields and create the page.
- Create a number of template pages and choose the created flip book page as parent. Fill the pages with content.
- Your main navigation now shows the flip book page. If you click on it, the first page is shown and "previous" and "next" buttons are shown.